# Installation
for now:

```
cd some-git-repo/
ln -s ~/puddl/ingress/git/post-commit .git/hooks/post-commit
```

later (not implemented):
```
cd some-git-repo/
puddl install ingress/git/post-commit
```
